## soifunc

Vapoursynth scripts that might be useful to someone

### Installation

#### Arch Linux

Install from [AUR](https://aur.archlinux.org/packages/vapoursynth-plugin-soifunc-git)

#### Other

First install the required plugins which are not available in pip:

- [neo_f3kdb](https://github.com/HomeOfAviSynthPlusEvolution/neo_f3kdb)
- [znedi3](https://github.com/sekrit-twc/znedi3)
- [nnedi3_resample](https://github.com/HomeOfVapourSynthEvolution/nnedi3_resample)

Install from pip:

```bash
pip install soifunc
```

Or the latest git version:

```bash
pip install git+https://github.com/shssoichiro/soifunc.git
```

### Usage

Please see the inline codedoc comments for usage details.
